@@ -5,7 +5,7 @@ from fastapi import Query
 from progress.bar import Bar
 from pydantic import BaseModel
 from pydantic.dataclasses import dataclass
-from pyimporters_plugins.base import KnowledgeParserBase, Term
+from pyimporters_plugins.base import KnowledgeParserBase, Term, KnowledgeParserOptions
 
 from pyimporters_csv.text import file_len, TXTOptions
 
@@ -69,9 +69,13 @@ class CSVKnowledgeParser(KnowledgeParserBase):
         bar.finish()
 
     @classmethod
-    def get_schema(cls) -> Type[BaseModel]:
+    def get_schema(cls) -> KnowledgeParserOptions:
         return CSVOptions
 
+    @classmethod
+    def get_model(cls) -> Type[BaseModel]:
+        return CSVOptionsModel
+
 def header_index(col):
     return int(col) if col.lstrip('+-').isdigit() else None
 
