@@ -5,7 +5,7 @@ from fastapi import Query
 from progress.bar import Bar
 from pydantic import Field, BaseModel
 from pydantic.dataclasses import dataclass
-from pyimporters_plugins.base import KnowledgeParserBase, Term
+from pyimporters_plugins.base import KnowledgeParserBase, Term, KnowledgeParserOptions
 
 from pyimporters_csv.text import TXTOptions
 
@@ -26,14 +26,6 @@ class ExcelOptions(TXTOptions):
     altLabel_cols: str = Query("altLabel",
                                description="Column(s) to use as the altLabel of the concept, either given as a (list of) string name(s) or column index(es)")
 
-
-    multivalue_separator : str = Field("|", description="Additional separator to split multivalued columns if any")
-    header : Optional[int] = Field(0, description="Row number (0-indexed) to use as the column names, leave blank if there is no header")
-    identifier_col : str = Field("identifier", description="Column to use as the identifier of the concept, either given as string name or column index, if not set use the prefLabel column")
-    prefLabel_col : str = Field("prefLabel", description="Column to use as the prefLabel of the concept, either given as string name or column index")
-    altLabel_cols : str = Field("altLabel", description="Column(s) to use as the altLabel of the concept, either given as a (list of) string name(s) or column index(es)")
-
-
 ExcelOptionsModel = ExcelOptions.__pydantic_model__
 
 class ExcelKnowledgeParser(KnowledgeParserBase):
@@ -71,9 +63,13 @@ class ExcelKnowledgeParser(KnowledgeParserBase):
         bar.finish()
 
     @classmethod
-    def get_schema(cls) -> Type[BaseModel]:
+    def get_schema(cls) -> KnowledgeParserOptions:
         return ExcelOptions
 
+    @classmethod
+    def get_model(cls) -> Type[BaseModel]:
+        return ExcelOptionsModel
+
 def col_index(col):
     return int(col) if col.lstrip('+-').isdigit() else col
 
