@@ -30,9 +30,13 @@ class TXTKnowledgeParser(KnowledgeParserBase):
         bar.finish()
 
     @classmethod
-    def get_schema(cls) -> Type[BaseModel]:
+    def get_schema(cls) -> KnowledgeParserOptions:
         return TXTOptions
 
+    @classmethod
+    def get_model(cls) -> Type[BaseModel]:
+        return TXTOptionsModel
+
 def file_len(input_file:Path):
   """ Count number of lines in a file."""
   with open(input_file) as f:
